//Import necessary modules from D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  area,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data => { 
// Assigning X axis data   
  const xValue = d => d.Year; 
  const xAxisLabel = 'Year';
// Assigning Y axis data 
  const yValue = d => d.AvgStockPrice;
  const yAxisLabel = 'Avg Stock Price';
  
  const margin = { top: 10, right: 40, bottom: 88, left: 120 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-30 - margin.bottom-20;
  
  // Determing the Scale for X axis
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
// Determing the Scale for Y axis  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

// POsitioning the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 // Assigning values to x axis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
 // Assigning values to y axis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
  ;
  	
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 4)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing a line and adding it to svg 
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data));
  
   const areaGenerator = area()
   .x(d => xScale(xValue(d)))
   .y0(innerHeight)
   .y1(d => yScale(yValue(d)));
     
  g.append('path')
  	.attr('class', 'area_chart')
  	.attr('d', areaGenerator(data));
};

// Loading and Parsing CSV data
csv('https://gist.githubusercontent.com/SureshJohnWesly11/3d7895bcad1dc688a64248c57b45a41f/raw/0639ca3048e34171ffed99c79dd5e0e0ffc2a27e/apple-stock-area.csv')
  .then(data => {
    data.forEach(d => {
    	d.AvgStockPrice = +d.AvgStockPrice;
      d.Year = new Date(d.Year)
    });

    render(data);
  })